#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright (C) 2021 tribe29 GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Float,
    Dictionary,
    Tuple,
    DualListChoice,
    TextAscii,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersEnvironment,
    HostRulespec,
)

from cmk.gui.plugins.wato.datasource_programs import RulespecGroupDatasourceProgramsCustom


def _parameter_valuespec_rki_covid_area():
    return Dictionary(elements=[
        ("weekIncidence",
         Tuple(
             title=_("Maximum week's incidence"),
             elements=[
                 Float(title=_("Warning at"), default_value=35.0),
                 Float(title=_("Critical at"), default_value=50.0),
             ],
         )),
    ],)


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="rki_covid_area",
        item_spec=lambda: TextAscii(title=_("Name of the service")),
        group=RulespecGroupCheckParametersEnvironment,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_rki_covid_area,
        title=lambda: _("Covid-19 Area Info from RKI"),
    ))

def _parameter_valuespec_rki_covid_country():
    return Dictionary(elements=[
        ("weekIncidence",
         Tuple(
             title=_("Maximum week's incidence"),
             elements=[
                 Float(title=_("Warning at"), default_value=35.0),
                 Float(title=_("Critical at"), default_value=50.0),
             ],
         )),
        ("r_value",
         Tuple(
             title=_("Maximum R value"),
             elements=[
                 Float(title=_("Warning at"), default_value=1.0),
                 Float(title=_("Critical at"), default_value=1.0),
             ],
         )),
    ],)


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="rki_covid_country",
        item_spec=lambda: TextAscii(title=_("Name of the service")),
        group=RulespecGroupCheckParametersEnvironment,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_rki_covid_country,
        title=lambda: _("Covid-19 Country Info from RKI"),
    ))

rki_states = [
         "Baden-Württemberg",
         "Bayern",
         "Berlin",
         "Brandenburg",
         "Bremen",
         "Hamburg",
         "Hessen",
         "Mecklenburg-Vorpommern",
         "Niedersachsen",
         "Nordrhein-Westfalen",
         "Rheinland-Pfalz",
         "Saarland",
         "Sachsen",
         "Sachsen-Anhalt",
         "Schleswig-Holstein",
         "Thüringen",
         ]

rki_counties = [
         "Baden-Württemberg",
         "LK Ahrweiler",
         "LK Aichach-Friedberg",
         "LK Alb-Donau-Kreis",
         "LK Altenburger Land",
         "LK Altenkirchen",
         "LK Altmarkkreis Salzwedel",
         "LK Alt\u00f6tting",
         "LK Alzey-Worms",
         "LK Amberg-Sulzbach",
         "LK Ammerland",
         "LK Anhalt-Bitterfeld",
         "LK Ansbach",
         "LK Aschaffenburg",
         "LK Augsburg",
         "LK Aurich",
         "LK Bad D\u00fcrkheim",
         "LK Bad Kissingen",
         "LK Bad Kreuznach",
         "LK Bad T\u00f6lz-Wolfratshausen",
         "LK Bamberg",
         "LK Barnim",
         "LK Bautzen",
         "LK Bayreuth",
         "LK Berchtesgadener Land",
         "LK Bergstra\u00dfe",
         "LK Bernkastel-Wittlich",
         "LK Biberach",
         "LK Birkenfeld",
         "LK Bitburg-Pr\u00fcm",
         "LK Bodenseekreis",
         "LK Borken",
         "LK Breisgau-Hochschwarzwald",
         "LK B\u00f6blingen",
         "LK B\u00f6rde",
         "LK Burgenlandkreis",
         "LK Calw",
         "LK Celle",
         "LK Cham",
         "LK Cloppenburg",
         "LK Coburg",
         "LK Cochem-Zell",
         "LK Coesfeld",
         "LK Cuxhaven",
         "LK Dachau",
         "LK Dahme-Spreewald",
         "LK Darmstadt-Dieburg",
         "LK Deggendorf",
         "LK Diepholz",
         "LK Dillingen a.d.Donau",
         "LK Dingolfing-Landau",
         "LK Dithmarschen",
         "LK Donau-Ries",
         "LK Donnersbergkreis",
         "LK D\u00fcren",
         "LK Ebersberg",
         "LK Eichsfeld",
         "LK Eichst\u00e4tt",
         "LK Elbe-Elster",
         "LK Emmendingen",
         "LK Emsland",
         "LK Ennepe-Ruhr-Kreis",
         "LK Enzkreis",
         "LK Erding",
         "LK Erlangen-H\u00f6chstadt",
         "LK Erzgebirgskreis",
         "LK Esslingen",
         "LK Euskirchen",
         "LK Forchheim",
         "LK Freising",
         "LK Freudenstadt",
         "LK Freyung-Grafenau",
         "LK Friesland",
         "LK F\u00fcrstenfeldbruck",
         "LK F\u00fcrth",
         "LK Fulda",
         "LK Garmisch-Partenkirchen",
         "LK Germersheim",
         "LK Gie\u00dfen",
         "LK Gifhorn",
         "LK Goslar",
         "LK Gotha",
         "LK Grafschaft Bentheim",
         "LK Greiz",
         "LK Gro\u00df-Gerau",
         "LK G\u00f6ppingen",
         "LK G\u00f6rlitz",
         "LK G\u00f6ttingen",
         "LK G\u00fcnzburg",
         "LK G\u00fctersloh",
         "LK Hameln-Pyrmont",
         "LK Harburg",
         "LK Harz",
         "LK Ha\u00dfberge",
         "LK Havelland",
         "LK Heidekreis",
         "LK Heidenheim",
         "LK Heilbronn",
         "LK Heinsberg",
         "LK Helmstedt",
         "LK Herford",
         "LK Hersfeld-Rotenburg",
         "LK Herzogtum Lauenburg",
         "LK Hildburghausen",
         "LK Hildesheim",
         "LK Hochsauerlandkreis",
         "LK Hochtaunuskreis",
         "LK Hof",
         "LK Hohenlohekreis",
         "LK Holzminden",
         "LK H\u00f6xter",
         "LK Ilm-Kreis",
         "LK Jerichower Land",
         "LK Kaiserslautern",
         "LK Karlsruhe",
         "LK Kassel",
         "LK Kelheim",
         "LK Kitzingen",
         "LK Kleve",
         "LK Konstanz",
         "LK Kronach",
         "LK Kulmbach",
         "LK Kusel",
         "LK Kyffh\u00e4userkreis",
         "LK Lahn-Dill-Kreis",
         "LK Landsberg a.Lech",
         "LK Landshut",
         "LK Leer",
         "LK Leipzig",
         "LK Lichtenfels",
         "LK Limburg-Weilburg",
         "LK Lindau",
         "LK Lippe",
         "LK L\u00f6rrach",
         "LK L\u00fcchow-Dannenberg",
         "LK L\u00fcneburg",
         "LK Ludwigsburg",
         "LK Ludwigslust-Parchim",
         "LK Main-Kinzig-Kreis",
         "LK Main-Spessart",
         "LK Main-Tauber-Kreis",
         "LK Main-Taunus-Kreis",
         "LK Mainz-Bingen",
         "LK Mansfeld-S\u00fcdharz",
         "LK Marburg-Biedenkopf",
         "LK Mayen-Koblenz",
         "LK Mecklenburgische Seenplatte",
         "LK Mei\u00dfen",
         "LK Merzig-Wadern",
         "LK Mettmann",
         "LK Miesbach",
         "LK Miltenberg",
         "LK Minden-L\u00fcbbecke",
         "LK Mittelsachsen",
         "LK M\u00e4rkischer Kreis",
         "LK M\u00e4rkisch-Oderland",
         "LK M\u00fchldorf a.Inn",
         "LK M\u00fcnchen",
         "LK Neckar-Odenwald-Kreis",
         "LK Neuburg-Schrobenhausen",
         "LK Neumarkt i.d.OPf.",
         "LK Neunkirchen",
         "LK Neustadt a.d.Aisch-Bad Windsheim",
         "LK Neustadt a.d.Waldnaab",
         "LK Neu-Ulm",
         "LK Neuwied",
         "LK Nienburg (Weser)",
         "LK Nordfriesland",
         "LK Nordhausen",
         "LK Nordsachsen",
         "LK Nordwestmecklenburg",
         "LK Northeim",
         "LK N\u00fcrnberger Land",
         "LK Oberallg\u00e4u",
         "LK Oberbergischer Kreis",
         "LK Oberhavel",
         "LK Oberspreewald-Lausitz",
         "LK Odenwaldkreis",
         "LK Oder-Spree",
         "LK Offenbach",
         "LK Oldenburg",
         "LK Olpe",
         "LK Ortenaukreis",
         "LK Osnabr\u00fcck",
         "LK Ostalbkreis",
         "LK Ostallg\u00e4u",
         "LK Osterholz",
         "LK Ostholstein",
         "LK Ostprignitz-Ruppin",
         "LK Paderborn",
         "LK Passau",
         "LK Peine",
         "LK Pfaffenhofen a.d.Ilm",
         "LK Pinneberg",
         "LK Pl\u00f6n",
         "LK Potsdam-Mittelmark",
         "LK Prignitz",
         "LK Rastatt",
         "LK Ravensburg",
         "LK Recklinghausen",
         "LK Regen",
         "LK Regensburg",
         "LK Rems-Murr-Kreis",
         "LK Rendsburg-Eckernf\u00f6rde",
         "LK Reutlingen",
         "LK Rhein-Erft-Kreis",
         "LK Rheingau-Taunus-Kreis",
         "LK Rhein-Hunsr\u00fcck-Kreis",
         "LK Rheinisch-Bergischer Kreis",
         "LK Rhein-Kreis Neuss",
         "LK Rhein-Lahn-Kreis",
         "LK Rhein-Neckar-Kreis",
         "LK Rhein-Pfalz-Kreis",
         "LK Rhein-Sieg-Kreis",
         "LK Rh\u00f6n-Grabfeld",
         "LK Rosenheim",
         "LK Rostock",
         "LK Rotenburg (W\u00fcmme)",
         "LK Roth",
         "LK Rottal-Inn",
         "LK Rottweil",
         "LK Saale-Holzland-Kreis",
         "LK Saalekreis",
         "LK Saale-Orla-Kreis",
         "LK Saalfeld-Rudolstadt",
         "LK Saarlouis",
         "LK Saar-Pfalz-Kreis",
         "LK Salzlandkreis",
         "LK Sankt Wendel",
         "LK Schaumburg",
         "LK Schleswig-Flensburg",
         "LK Schmalkalden-Meiningen",
         "LK Schwalm-Eder-Kreis",
         "LK Schwandorf",
         "LK Schwarzwald-Baar-Kreis",
         "LK Schweinfurt",
         "LK Schw\u00e4bisch Hall",
         "LK Segeberg",
         "LK Siegen-Wittgenstein",
         "LK Sigmaringen",
         "LK Soest",
         "LK Sonneberg",
         "LK Spree-Nei\u00dfe",
         "LK Stade",
         "LK Stadtverband Saarbr\u00fccken",
         "LK Starnberg",
         "LK Steinburg",
         "LK Steinfurt",
         "LK Stendal",
         "LK Stormarn",
         "LK Straubing-Bogen",
         "LK S\u00e4chsische Schweiz-Osterzgebirge",
         "LK S\u00f6mmerda",
         "LK S\u00fcdliche Weinstra\u00dfe",
         "LK S\u00fcdwestpfalz",
         "LK Teltow-Fl\u00e4ming",
         "LK Tirschenreuth",
         "LK Traunstein",
         "LK Trier-Saarburg",
         "LK T\u00fcbingen",
         "LK Tuttlingen",
         "LK Uckermark",
         "LK Uelzen",
         "LK Unna",
         "LK Unstrut-Hainich-Kreis",
         "LK Unterallg\u00e4u",
         "LK Vechta",
         "LK Verden",
         "LK Viersen",
         "LK Vogelsbergkreis",
         "LK Vogtlandkreis",
         "LK Vorpommern-Greifswald",
         "LK Vorpommern-R\u00fcgen",
         "LK Vulkaneifel",
         "LK Waldeck-Frankenberg",
         "LK Waldshut",
         "LK Warendorf",
         "LK Wartburgkreis",
         "LK Weilheim-Schongau",
         "LK Weimarer Land",
         "LK Wei\u00dfenburg-Gunzenhausen",
         "LK Werra-Mei\u00dfner-Kreis",
         "LK Wesel",
         "LK Wesermarsch",
         "LK Westerwaldkreis",
         "LK Wetteraukreis",
         "LK Wittenberg",
         "LK Wittmund",
         "LK Wolfenb\u00fcttel",
         "LK W\u00fcrzburg",
         "LK Wunsiedel i.Fichtelgebirge",
         "LK Zollernalbkreis",
         "LK Zwickau",
         "Region Hannover",
         "SK Amberg",
         "SK Ansbach",
         "SK Aschaffenburg",
         "SK Augsburg",
         "SK Baden-Baden",
         "SK Bamberg",
         "SK Bayreuth",
         "SK Berlin Charlottenburg-Wilmersdorf",
         "SK Berlin Friedrichshain-Kreuzberg",
         "SK Berlin Lichtenberg",
         "SK Berlin Marzahn-Hellersdorf",
         "SK Berlin Mitte",
         "SK Berlin Neuk\u00f6lln",
         "SK Berlin Pankow",
         "SK Berlin Reinickendorf",
         "SK Berlin Spandau",
         "SK Berlin Steglitz-Zehlendorf",
         "SK Berlin Tempelhof-Sch\u00f6neberg",
         "SK Berlin Treptow-K\u00f6penick",
         "SK Bielefeld",
         "SK Bochum",
         "SK Bonn",
         "SK Bottrop",
         "SK Brandenburg a.d.Havel",
         "SK Braunschweig",
         "SK Bremen",
         "SK Bremerhaven",
         "SK Chemnitz",
         "SK Coburg",
         "SK Cottbus",
         "SK Darmstadt",
         "SK Delmenhorst",
         "SK Dessau-Ro\u00dflau",
         "SK Dortmund",
         "SK Dresden",
         "SK D\u00fcsseldorf",
         "SK Duisburg",
         "SK Eisenach",
         "SK Emden",
         "SK Erfurt",
         "SK Erlangen",
         "SK Essen",
         "SK Flensburg",
         "SK Frankenthal",
         "SK Frankfurt am Main",
         "SK Frankfurt (Oder)",
         "SK Freiburg i.Breisgau",
         "SK F\u00fcrth",
         "SK Gelsenkirchen",
         "SK Gera",
         "SK Hagen",
         "SK Halle",
         "SK Hamburg",
         "SK Hamm",
         "SK Heidelberg",
         "SK Heilbronn",
         "SK Herne",
         "SK Hof",
         "SK Ingolstadt",
         "SK Jena",
         "SK Kaiserslautern",
         "SK Karlsruhe",
         "SK Kassel",
         "SK Kaufbeuren",
         "SK Kempten",
         "SK Kiel",
         "SK Koblenz",
         "SK Krefeld",
         "SK K\u00f6ln",
         "SK Landau i.d.Pfalz",
         "SK Landshut",
         "SK Leipzig",
         "SK Leverkusen",
         "SK L\u00fcbeck",
         "SK Ludwigshafen",
         "SK Magdeburg",
         "SK Mainz",
         "SK Mannheim",
         "SK Memmingen",
         "SK M\u00f6nchengladbach",
         "SK M\u00fclheim a.d.Ruhr",
         "SK M\u00fcnchen",
         "SK M\u00fcnster",
         "SK Neum\u00fcnster",
         "SK Neustadt a.d.Weinstra\u00dfe",
         "SK N\u00fcrnberg",
         "SK Oberhausen",
         "SK Offenbach",
         "SK Oldenburg",
         "SK Osnabr\u00fcck",
         "SK Passau",
         "SK Pforzheim",
         "SK Pirmasens",
         "SK Potsdam",
         "SK Regensburg",
         "SK Remscheid",
         "SK Rosenheim",
         "SK Rostock",
         "SK Salzgitter",
         "SK Schwabach",
         "SK Schweinfurt",
         "SK Schwerin",
         "SK Solingen",
         "SK Speyer",
         "SK Straubing",
         "SK Stuttgart",
         "SK Suhl",
         "SK Trier",
         "SK Ulm",
         "SK Weiden i.d.OPf.",
         "SK Weimar",
         "SK Wiesbaden",
         "SK Wilhelmshaven",
         "SK Wolfsburg",
         "SK Worms",
         "SK W\u00fcrzburg",
         "SK Wuppertal",
         "SK Zweibr\u00fccken",
         "StadtRegion Aachen",
]


def _valuespec_special_agents_rki():
    return Dictionary(
        title=_("RKI Special Agent"),
        help=_("To monitor RKI Covid API add this datasource to <b>one</b> host. "),
        # element names starting with "--" will be passed do cmd line w/o parsing!
        elements=[
            ("rki_url", TextAscii(
                title=_("URL"),
                allow_empty=False,
                default_value="https://api.corona-zahlen.org",
                size=128,
            )),
            ("rki_counties",
                DualListChoice(
                    title=_("Counties"),
                    rows=40,
                    choices=[(entry, entry) for entry in rki_counties],
            )),
            ("rki_states",
                DualListChoice(
                    title=_("States"),
                    rows=40,
                    choices=[(entry, entry) for entry in rki_states],
            )),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupDatasourceProgramsCustom,
        name="special_agents:rki",
        valuespec=_valuespec_special_agents_rki,
    ))

